@@ -1,7 +1,7 @@
 # =============================================================================
 #
 #    Remuco - A remote control system for media players.
-#    Copyright (C) 2006-2009 Oben Sonne <obensonne@googlemail.com>
+#    Copyright (C) 2006-2009 by the Remuco team, see AUTHORS.
 #
 #    This file is part of Remuco.
 #
@@ -380,15 +380,6 @@ class PlayerAdapter(object):
         As above, only override the methods which make sense for the
         corresponding media player.
     
-    ===========================================================================
-    Methods to call to respond to the requests above:
-    ===========================================================================
-
-        * reply_playlist_request()
-        * reply_queue_request()
-        * reply_mlib_request()
-        * reply_search_request()
-        
     ===========================================================================
     Methods to call to synchronize media player state information with clients:
     ===========================================================================
@@ -1128,12 +1119,10 @@ class PlayerAdapter(object):
             progress -= off
         else:
             progress += (5 - off)
-        progress = min(length, progress)
-        
-        #diff = abs(self.__progress.progress - progress)
+        if length > 0:
+            progress = min(length, progress)
         
         change = self.__progress.length != length
-        #change |= diff >= 5
         change |= self.__progress.progress != progress
         
         if change:
