@@ -1,7 +1,7 @@
 # =============================================================================
 #
 #    Remuco - A remote control system for media players.
-#    Copyright (C) 2006-2009 Oben Sonne <obensonne@googlemail.com>
+#    Copyright (C) 2006-2009 by the Remuco team, see AUTHORS.
 #
 #    This file is part of Remuco.
 #
@@ -37,16 +37,16 @@ DEVICE_FILE = os.path.join(xdg_cache, "remuco", "devices")
 SEC = ConfigParser.DEFAULTSECT
 
 CONFIG_VERSION_MAJOR = "1"
-CONFIG_VERSION_MINOR = "3"
+CONFIG_VERSION_MINOR = "4"
 CONFIG_VERSION = "%s.%s" % (CONFIG_VERSION_MAJOR, CONFIG_VERSION_MINOR)
 
 KEY_CONFIG_VERSION = "config-version"
 KEY_BLUETOOTH = "bluetooth-enabled"
+KEY_BLUETOOTH_CHAN = "bluetooth-channel"
 KEY_WIFI = "wifi-enabled"
 KEY_WIFI_PORT = "wifi-port"
 KEY_ENDCODING = "player-encoding"
 KEY_LOGLEVEL = "log-level"
-KEY_PING = "ping-interval"
 KEY_FB = "file-browser-enabled"
 KEY_FB_SHOW_EXT = "file-browser-show-extensions"
 KEY_FB_ROOT_DIRS = "file-browser-root-dirs"
@@ -54,11 +54,11 @@ KEY_FB_XDG_UD = "file-browser-use-xdg-user-dirs"
 
 DEFAULTS = { # values as saved in config file
     KEY_BLUETOOTH: "1",
+    KEY_BLUETOOTH_CHAN: "0",
     KEY_WIFI: "1",
     KEY_WIFI_PORT: "34271",
     KEY_ENDCODING: "UTF8",
     KEY_LOGLEVEL: "INFO",
-    KEY_PING: "15",
     KEY_FB: "1",
     KEY_FB_SHOW_EXT: "0",
     KEY_FB_ROOT_DIRS: "",
@@ -249,6 +249,30 @@ class Config(object):
     bluetooth = property(__pget_bluetooth, __pset_bluetooth, None,
                          __pget_bluetooth.__doc__)
 
+    # === property: bluetooth_channel ===
+    
+    def __pget_bluetooth_channel(self):
+        """Channel to use for Bluetooth connections.
+        
+        Default: 0 (select channel automatically)
+        
+        Option name: 'bluetooth-channel'
+        """
+        try:
+            return self.__cp.getint(SEC, KEY_BLUETOOTH_CHAN)
+        except (ValueError, AttributeError), e:
+            log.warning("config '%s' malformed (%s)" % (KEY_BLUETOOTH_CHAN, e))
+            return 0
+    
+    def __pset_bluetooth_channel(self, value):
+        
+        self.__cp.set(SEC, KEY_BLUETOOTH_CHAN, str(value))
+        self.__save()
+    
+    bluetooth_channel = property(__pget_bluetooth_channel,
+                                 __pset_bluetooth_channel, None,
+                                 __pget_bluetooth_channel.__doc__)
+    
     # === property: wifi ===
     
     def __pget_wifi(self):
@@ -366,31 +390,6 @@ class Config(object):
     log_level = property(__pget_log_level, __pset_log_level, None,
                          __pget_log_level.__doc__)
 
-    # === property: ping ===
-    
-    def __pget_ping(self):
-        """Interval in seconds for sending a ping to clients.
-        
-        An interval of 0 disables ping.
-        
-        Default: 15
-        
-        Option name: 'ping-interval'
-
-        """
-        try:
-            return self.__cp.getint(SEC, KEY_PING)
-        except (ValueError, AttributeError), e:
-            log.warning("config '%s' malformed (%s)" % (KEY_PING, e))
-            return 15
-        
-    def __pset_ping(self, value):
-
-        self.__cp.set(SEC, KEY_PING, str(value))
-        self.__save()
-    
-    ping = property(__pget_ping, __pset_ping, None, __pget_ping.__doc__)
-
     # === property: fb ===
     
     def __pget_fb(self):
