@@ -1,6 +1,6 @@
 /*   
  *   Remuco - A remote control system for media players.
- *   Copyright (C) 2006-2009 Oben Sonne <obensonne@googlemail.com>
+ *   Copyright (C) 2006-2009 by the Remuco team, see AUTHORS.
  *
  *   This file is part of Remuco.
  *
@@ -20,21 +20,14 @@
  */
 package remuco.comm;
 
-import remuco.Config;
-
 public interface IDeviceSelectionListener {
 
 	/**
 	 * Notify a device selection.
 	 * 
-	 * @param type
-	 *            the type of the selected device
-	 * @param addr
-	 *            the address of the selected device
-	 * 
-	 * @see Config#DEVICE_TYPE_BLUETOOTH
-	 * @see Config#DEVICE_TYPE_INET
+	 * @param iDevice
+	 *            the selected device
 	 */
-	public void notifySelectedDevice(String type, String addr);
+	public void notifySelectedDevice(IDevice iDevice);
 
 }
