@@ -1,6 +1,6 @@
 /*   
  *   Remuco - A remote control system for media players.
- *   Copyright (C) 2006-2009 Oben Sonne <obensonne@googlemail.com>
+ *   Copyright (C) 2006-2009 by the Remuco team, see AUTHORS.
  *
  *   This file is part of Remuco.
  *
@@ -24,9 +24,6 @@ package remuco.comm;
  * Interface for classes interested in device scan results.
  * 
  * @see IScanner#startScan(IScanListener)
- * 
- * @author Oben Sonne
- * 
  */
 public interface IScanListener {
 
@@ -34,11 +31,8 @@ public interface IScanListener {
 	 * Hands out the found devices.
 	 * 
 	 * @param devices
-	 *            the found devices, where element <code>3 * i</code> is the
-	 *            address of device <code>i</code>, element
-	 *            <code>3 * i + 1</code> its name and element
-	 *            <code>3 * i + 2</code> its type
+	 *            the found devices
 	 */
-	public void notifyScannedDevices(String[] devices);
+	public void notifyScannedDevices(BluetoothDevice devices[]);
 
 }
