@@ -1,6 +1,6 @@
 /*   
  *   Remuco - A remote control system for media players.
- *   Copyright (C) 2006-2009 Oben Sonne <obensonne@googlemail.com>
+ *   Copyright (C) 2006-2009 by the Remuco team, see AUTHORS.
  *
  *   This file is part of Remuco.
  *
@@ -22,12 +22,7 @@ package remuco.comm;
 
 import remuco.UserException;
 
-/**
- * A finder searching for Remuco services.
- * 
- * @author Oben Sonne
- * 
- */
+/** A finder searching for Remuco services. */
 public interface IServiceFinder {
 
 	/**
@@ -38,15 +33,15 @@ public interface IServiceFinder {
 	/**
 	 * Find all available Remuco services on a device.
 	 * 
-	 * @param addr
-	 *            address of the device to search for services
+	 * @param iDevice
+	 *            device to search for services
 	 * @param listener
 	 *            the {@link IServiceListener} to notify if service search is
 	 *            finished
 	 * @throws UserException
 	 *             if there was an error in starting the search
 	 */
-	public void findServices(String addr, IServiceListener listener)
+	public void findServices(IDevice iDevice, IServiceListener listener)
 			throws UserException;
 
 }
\ No newline at end of file
