@@ -1,6 +1,6 @@
 /*   
  *   Remuco - A remote control system for media players.
- *   Copyright (C) 2006-2009 Oben Sonne <obensonne@googlemail.com>
+ *   Copyright (C) 2006-2009 by the Remuco team, see AUTHORS.
  *
  *   This file is part of Remuco.
  *
@@ -20,8 +20,6 @@
  */
 package remuco.ui.screens;
 
-import java.util.Timer;
-
 import javax.microedition.lcdui.Alert;
 import javax.microedition.lcdui.AlertType;
 import javax.microedition.lcdui.Canvas;
@@ -30,26 +28,22 @@ import javax.microedition.lcdui.CommandListener;
 import javax.microedition.lcdui.Display;
 import javax.microedition.lcdui.Displayable;
 import javax.microedition.lcdui.Graphics;
+import javax.microedition.lcdui.Image;
 
 import remuco.Config;
 import remuco.IOptionListener;
+import remuco.MainLoop;
 import remuco.OptionDescriptor;
-import remuco.Remuco;
-import remuco.comm.BinaryDataExecption;
-import remuco.comm.Connection;
-import remuco.comm.Message;
 import remuco.player.Feature;
 import remuco.player.IItemListener;
 import remuco.player.IProgressListener;
 import remuco.player.IStateListener;
 import remuco.player.Item;
 import remuco.player.Player;
-import remuco.player.PlayerInfo;
 import remuco.ui.CMD;
 import remuco.ui.CommandList;
 import remuco.ui.IActionListener;
 import remuco.ui.KeyBindings;
-import remuco.ui.MediaBrowser;
 import remuco.ui.RepeatedControl;
 import remuco.ui.Theme;
 import remuco.ui.screenies.ButtonBarScreeny;
@@ -66,6 +60,9 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 		IStateListener, IProgressListener, CommandListener, IActionListener,
 		IOptionListener {
 
+	public static final OptionDescriptor OD_IMG_KEEPFS = new OptionDescriptor(
+			"keep-img-fs", "Image fullscreen persistent", "No", "Yes,No");
+
 	/**
 	 * A wrapper command for the command {@link CMD#BACK} added externally to
 	 * this screen.
@@ -74,7 +71,7 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 			Command.SCREEN, 92);
 
 	private static final Command CMD_KEYS = new Command("Key Bindings",
-			Command.SCREEN, 2);
+			Command.SCREEN, 3);
 
 	private static final Command CMD_MEDIA = new Command("Media",
 			Command.SCREEN, 1);
@@ -82,7 +79,7 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 	private static final Command CMD_MENU = new Command("Menu", Command.BACK, 2);
 
 	private static final Command CMD_OPTIONS = new Command("Options",
-			Command.SCREEN, 3);
+			Command.SCREEN, 2);
 
 	private static final Command CMD_SHUTDOWN_HOST = new Command(
 			"Shutdown Host", Command.SCREEN, 95);
@@ -93,17 +90,18 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 
 	private final Config config;
 
-	private final Connection conn;
-
 	private final Display display;
 
-	private CommandListener externalCommandListener = null;
+	private CommandListener externalCommandListener;
 
 	/** Indicates if the item's image is currently shown in fullscreen mode. */
-	private boolean itemImageFullscreen;
+	private boolean itemImageFullscreenActive;
 
-	/** Screen for browsing the remote player's media */
-	private final MediaBrowser mediaBrowser;
+	/**
+	 * Indicates if the item's image (if there is one) is <em>supposed</em> to
+	 * be shown in fullscreen mode.
+	 */
+	private boolean itemImageFullscreenEnabled;
 
 	private final Player player;
 
@@ -114,6 +112,9 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 	/** Screen to configure key setup */
 	private final KeyBindingsScreen screenKeyConfig;
 
+	/** Screen for browsing the remote player's media */
+	private final MediaBrowserScreen screenMediaBrowser;
+
 	private final CommandList screenMenu;
 
 	private final OptionsScreen screenOptions;
@@ -135,8 +136,6 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 
 	private final Theme theme;
 
-	private final Timer timer;
-
 	/**
 	 * Create a new player screen.
 	 * 
@@ -147,30 +146,27 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 	 * @param pinfo
 	 *            information about the remote player
 	 */
-	public PlayerScreen(Display display, Connection conn, PlayerInfo pinfo) {
+	public PlayerScreen(Display display, Player player) {
 
 		this.display = display;
-		this.conn = conn;
-
-		timer = Remuco.getGlobalTimer();
 
 		theme = Theme.getInstance();
 
-		player = new Player(conn, pinfo);
+		this.player = player;
 
 		player.setStateListener(this);
 		player.setItemListener(this);
 		player.setProgressListener(this);
 
-		if (pinfo.supportsMediaBrowser()) {
+		if (player.info.supportsMediaBrowser()) {
 			super.addCommand(CMD_MEDIA);
 		}
 		super.addCommand(CMD_MENU);
-		super.setCommandListener(this);
+		setCommandListener(this);
 
-		screenMenu = new CommandList("Options");
+		screenMenu = new CommandList("Menu");
 		screenMenu.addCommand(CMD_KEYS, theme.licKeys);
-		if (pinfo.supports(Feature.SHUTDOWN)) {
+		if (player.info.supports(Feature.SHUTDOWN)) {
 			screenMenu.addCommand(CMD_SHUTDOWN_HOST, theme.licOff);
 		}
 		screenMenu.addCommand(CMD.BACK);
@@ -183,8 +179,9 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 		screenyButtons = new ButtonBarScreeny(player.info);
 		screenyProgress = new ProgressScreeny(player.info);
 
-		screenKeyConfig = new KeyBindingsScreen(this, display);
+		screenKeyConfig = new KeyBindingsScreen(display);
 		screenKeyConfig.addCommand(CMD.BACK);
+		screenKeyConfig.setCommandListener(this);
 
 		screenOptions = new OptionsScreen();
 		screenOptions.addCommand(CMD.BACK);
@@ -197,7 +194,9 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 
 		alertFeature = new Alert("", "", null, AlertType.INFO);
 
-		mediaBrowser = new MediaBrowser(this, display, player);
+		screenMediaBrowser = new MediaBrowserScreen(display, player);
+		screenMediaBrowser.addCommand(CMD.BACK);
+		screenMediaBrowser.setCommandListener(this);
 
 		config = Config.getInstance();
 		config.addOptionListener(this);
@@ -237,15 +236,19 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 
 	public void commandAction(Command c, Displayable d) {
 
-		if (c == CMD_MEDIA) {
+		if (c == CMD_MEDIA) { // MEDIA //
 
-			mediaBrowser.showYourself();
+			display.setCurrent(screenMediaBrowser);
 
-		} else if (c == CMD_MENU) {
+		} else if (c == CMD.BACK && d == screenMediaBrowser) {
+
+			display.setCurrent(this);
+
+		} else if (c == CMD_MENU) { // OPTIONS //
 
 			display.setCurrent(screenMenu);
 
-		} else if (c == CMD.BACK && d == screenMenu) { // OPTIONS //
+		} else if (c == CMD.BACK && d == screenMenu) {
 
 			display.setCurrent(this);
 
@@ -305,13 +308,8 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 		}
 	}
 
-	/** Do some clean up before this player screen gets finally disposed. */
-	public void dispose() {
-
-		stopVolumeControl();
-		stopSeek();
-		conn.down();
-
+	public Player getPlayer() {
+		return player;
 	}
 
 	public void handleActionPressed(int action) {
@@ -412,16 +410,13 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 
 		case KeyBindings.ACTION_IMAGE:
 
-			if (itemImageFullscreen) {
-				itemImageFullscreen = false;
-				repaint(); // repaint all on fullscreen change
-			} else {
-				if (player.item.getImg() != null) {
-					itemImageFullscreen = true;
-					screenyItemImageFullscreen.updateData(player.item.getImg());
-					repaint(); // repaint all on fullscreen change
-				}
+			final Image itemImage = player.item.getImg();
+			if (itemImage == null) {
+				break; // ignore fullscreen toggles when there is no image
 			}
+			itemImageFullscreenEnabled = !itemImageFullscreenEnabled;
+			itemImageFullscreenActive = itemImageFullscreenEnabled;
+			repaint(); // repaint all on fullscreen change
 
 			break;
 
@@ -521,18 +516,23 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 
 	}
 
-	public void handleMessageForPlayer(Message msg) throws BinaryDataExecption {
-		player.handleMessage(msg);
+	public boolean isSessionOptionListener() {
+		return true;
 	}
 
 	public void notifyItemChanged() {
 
 		screenyItem.updateData(player.item);
-		if (itemImageFullscreen) {
-			itemImageFullscreen = false;
-			repaint(screenyItemImageFullscreen);
-		} else {
+		screenyItemImageFullscreen.updateData(player.item.getImg());
+
+		if (!itemImageFullscreenEnabled) {
 			repaint(screenyItem);
+		} else {
+			itemImageFullscreenEnabled = config.getOption(OD_IMG_KEEPFS)
+					.equalsIgnoreCase("yes");
+			itemImageFullscreenActive = itemImageFullscreenEnabled
+					&& player.item.getImg() != null;
+			repaint(screenyItemImageFullscreen);
 		}
 	}
 
@@ -560,9 +560,12 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 
 	}
 
-	/** Set an <em>external</em> command listener. */
 	public void setCommandListener(CommandListener l) {
-		externalCommandListener = l;
+		if (l == this) {
+			super.setCommandListener(l);
+		} else {
+			externalCommandListener = l;
+		}
 	}
 
 	protected void keyPressed(int key) {
@@ -588,7 +591,7 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 
 		if (screenTooSmall) {
 			drawScreenTooSmallMessage(g);
-		} else if (itemImageFullscreen) {
+		} else if (itemImageFullscreenActive) {
 			screenyItemImageFullscreen.draw(g);
 		} else {
 			screenyState.draw(g);
@@ -602,7 +605,7 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 
 		if (screenTooSmall) { // ignore pointer events
 			commandAction(CMD_OPTIONS, this);
-		} else if (itemImageFullscreen) {
+		} else if (itemImageFullscreenActive) {
 			handleActionPressed(KeyBindings.ACTION_IMAGE);
 		} else {
 			screenyState.pointerPressed(x, y, this);
@@ -612,7 +615,7 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 	}
 
 	protected void pointerReleased(int x, int y) {
-		if (!itemImageFullscreen && !screenTooSmall) {
+		if (!itemImageFullscreenActive && !screenTooSmall) {
 			screenyState.pointerReleased(x, y, this);
 			screenyItem.pointerReleased(x, y, this);
 			screenyButtons.pointerReleased(x, y, this);
@@ -773,7 +776,7 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 			recoSeek.cancel();
 		}
 		recoSeek = new RepeatedControl(RepeatedControl.SEEK, player, direction);
-		timer.schedule(recoSeek, SEEK_DELAY, 321);
+		MainLoop.schedule(recoSeek, SEEK_DELAY, 321);
 	}
 
 	private void startVolumeControl(int direction) {
@@ -783,7 +786,7 @@ public final class PlayerScreen extends Canvas implements IItemListener,
 		}
 		recoVolume = new RepeatedControl(RepeatedControl.VOLUME, player,
 				direction);
-		timer.schedule(recoVolume, 0, 253);
+		MainLoop.schedule(recoVolume, 0, 253);
 	}
 
 	/**
